## py3dtiles

Py3dtiles is a python library and command-line tool designed for generating and managing 3D Tiles datasets, the OGC standard for streaming massive 3D geospatial content.

## Features

Read

from various sources

pointclouds (las, laz, xyz, csv, ply…), geometries (wkb, ifc…)

Write

your tileset and tiles

tileset.json, b3dm, pnts...

Manipulate

everything!

includes classes and methods to easily edit your tilesets and your tiles.

CLI

Get started quickly with our command-line tool

Py3dtiles icludes a command line tool to quickly get informations about 3dtiles files or convert datasets.

    py3dtiles convert --out="3dtiles" pointcloud.las

API

Integrate py3dtiles directly in your python app

Py3dtiles includes a rich API to read, write and manipulates 3dtiles datasets

    import json
    from pathlib import Path

    from py3dtiles.tileset import TileSet

    tileset_path = Path("tests/fixtures/tiles/tileset.json")
    with tileset_path.open() as f:
        tileset = TileSet.from_dict(json.load(f))

Get started now!

## Showcases

Py3dtiles aims at being a swiss knife for converting and editing tilesets. It can read and create tilesets and tilesets content. For file conversion, it currently supports various pointclouds format (las, xyz, ply...), wkb and ifc files.
It can be extended to add your own pointcloud reader or geometry tiler. Lib usage allows it to be integrated into a larger application or into data pipelines.

## Sponsors